@@ -13,7 +13,7 @@ wsData = {"CURRENT_URL": None}
 connectionsKept = []
 
 class get:
-    def __init__(self, wsUrl, headers=None, encryption=None, identifiers=None, timeout=None, debug=False):
+    def __init__(self, wsUrl, headers={}, encryption=None, identifiers=None, timeout=None, debug=False):
         global ws
         if wsUrl != wsData["CURRENT_URL"]:
             wsData["CURRENT_URL"] = wsUrl
@@ -58,7 +58,7 @@ class get:
         return JSON.loads(self.text)
 
 class post:
-    def __init__(self, wsUrl, headers=None, encryption=None, data=None, json=None, identifiers=None, waitForResponse=True, timeout=None, debug=False):
+    def __init__(self, wsUrl, headers={}, encryption=None, data=None, json=None, identifiers=None, waitForResponse=True, timeout=None, debug=False):
         global ws
 
         if data == None and json == None:
